+++
title = "Event tree analysis"
date = "2015-03-14T00:50:02"
source = "https://en.wikipedia.org/wiki/Event_tree_analysis"
categories = [ "games", "music", "art", "home" ]
tags = [ "orange", "indigo", "blue", "violet", "yellow" ]

+++

**Event tree analysis** (**ETA**) is a forward, bottom up, logical modeling technique for both success and failure that explores responses through a single initiating event and lays a path for assessing probabilities of the outcomes and overall system analysis.<sup>[\[1\]](#cite_note-Clemments_1-1)</sup> This analysis technique is used to analyze the effects of functioning or failed systems given that an event has occurred.<sup>[\[2\]](#cite_note-wang69-2)</sup> ETA is a powerful tool that will identify all consequences of a system that have a probability of occurring after an initiating event that can be applied to a wide range of systems including: <a href="//en.wikipedia.org/wiki/Nuclear_power_plants" class="mw-redirect" title="Nuclear power plants">nuclear power plants</a>, [spacecraft](//en.wikipedia.org/wiki/Spacecraft "Spacecraft"), and chemical plants. This Technique may be applied to a system early in the design process to identify potential issues that may arise rather than correcting the issues after they occur.<sup>[\[3\]](#cite_note-Clifton-3)</sup> With this forward logic process use of ETA as a tool in risk assessment can help to prevent negative outcomes from occurring by providing a risk assessor with the probability of occurrence. ETA uses a type of modeling technique called [event tree](//en.wikipedia.org/wiki/Event_tree "Event tree"), which branches events from one single event using <a href="//en.wikipedia.org/wiki/Boolean_logic" class="mw-redirect" title="Boolean logic">Boolean logic</a>.

Contents
--------

-   [<span class="tocnumber">1</span> <span class="toctext">History</span>](#History)
-   [<span class="tocnumber">2</span> <span class="toctext">Theory</span>](#Theory)
-   [<span class="tocnumber">3</span> <span class="toctext">Methodology</span>](#Methodology)
-   [<span class="tocnumber">4</span> <span class="toctext">Mathematical concepts</span>](#Mathematical_concepts)
-   [<span class="tocnumber">5</span> <span class="toctext">In risk analysis</span>](#In_risk_analysis)
-   [<span class="tocnumber">6</span> <span class="toctext">Advantages</span>](#Advantages)
-   [<span class="tocnumber">7</span> <span class="toctext">Limitations</span>](#Limitations)
-   [<span class="tocnumber">8</span> <span class="toctext">Software</span>](#Software)
-   [<span class="tocnumber">9</span> <span class="toctext">References</span>](#References)

<span id="History" class="mw-headline">History</span>
-----------------------------------------------------

The name Event Tree was first introduced during the [WASH-1400](//en.wikipedia.org/wiki/WASH-1400 "WASH-1400") nuclear power plant safety study (circa 1974) where the [WASH-1400](//en.wikipedia.org/wiki/WASH-1400 "WASH-1400") team needed an alternate method to [fault tree analysis](//en.wikipedia.org/wiki/Fault_tree_analysis "Fault tree analysis") due to the fault trees being too large. Though not using the name event tree the UKAEA first introduced ETA in its design offices in 1968. Initially to try to use whole plant risk assessment to optimize the design of a 500MW Steam Generating Heavy Water Reactor. This study showed ETA condensed the analysis into a manageable form.<sup>[\[1\]](#cite_note-Clemments_1-1)</sup> ETA was not initially developed during WASH-1400, this was one of the first cases in which it was thoroughly used. The UKAEA study used the assumption that protective systems either worked or failed, with the probability of failure per demand being calculated using fault trees or similar analysis methods. ETA identifies all sequences which follow an initiating event. Many of these sequences can be eliminated from the analysis because their frequency or effect are too small to affect the overall result. A paper presented at a CREST symposium in Munich,Germany in 1971<sup>[\[2\]](#cite_note-wang69-2)</sup> shows how this was done. The conclusions of the US EPA study of the Draft WASH-1400<sup>[\[3\]](#cite_note-Clifton-3)</sup> acknowledges the role of Ref 1 and its criticism of the Maximum Credible Accident approach used by AEC. MCA sets the reliability target for the containment but those for all other safety systems are set by smaller but more frequent accidents and would be missed by MCA.

In 2009 a risk analysis was conducted on underwater tunnel excavation under the [Han River](//en.wikipedia.org/wiki/Han_River_(Korea) "Han River (Korea)") in [Korea](//en.wikipedia.org/wiki/Korea "Korea") using an earth pressure balance type [tunnel boring machine](//en.wikipedia.org/wiki/Tunnel_boring_machine "Tunnel boring machine"). ETA was used to quantify risk, by providing the probability of occurrence of an event, in the preliminary design stages of the tunnel construction to prevent any injuries or fatalities because tunnel construction in Korea has the highest injury and fatality rates within the construction category.<sup>[\[4\]](#cite_note-Eun-Soo-4)</sup>

<span id="Theory" class="mw-headline">Theory</span>
---------------------------------------------------

Performing a [probabilistic risk assessment](//en.wikipedia.org/wiki/Probabilistic_risk_assessment "Probabilistic risk assessment") starts with a set of initiating events that change the state or configuration of the system.<sup>[\[3\]](#cite_note-Clifton-3)</sup> An initiating event is an event that starts a reaction, such as the way a spark (initiating event) can start a fire that could lead to other events (intermediate events) such as a tree burning down, and then finally an outcome, for example, the burnt tree no longer provides apples for food. Each initiating event leads to another event and continuing through this path, where each intermediate events probability of occurrence may be calculated by using fault tree analysis, until an end state is reached (the outcome of a tree no longer providing apples for food).<sup>[\[3\]](#cite_note-Clifton-3)</sup> Intermediate events are commonly split into a [binary](//en.wikipedia.org/wiki/Binary_number "Binary number") (success/failure or yes/no) but may be split into more than two as long as the events are <a href="//en.wikipedia.org/wiki/Mutually_exclusive" class="mw-redirect" title="Mutually exclusive">mutually exclusive</a>, meaning that they can not occur at the same time. If a spark is the initiating event there is a probability that the spark will start a fire or will not start a fire (binary yes or no) as well as the probability that the fire spreads to a tree or does not spread to a tree. End states are classified into groups that can be successes or severity of consequences. An example of a success would be that no fire started and the tree still provided apples for food while the severity of consequence would be that a fire did start and we lose apples as a source of food. Loss end states can be any state at the end of the pathway that is a negative outcome of the initiating event. The loss end state is highly dependent upon the system, for example if you were measuring a quality process in a factory a loss or end state would be that the product has to be reworked or thrown in the trash. Some common loss end states:<sup>[\[3\]](#cite_note-Clifton-3)</sup>

-   Loss of Life or Injury/ Illness to personnel<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Damage to or loss of equipment or property (including software)<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Unexpected or collateral damage as a result of tests
-   Failure of mission<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Loss of system availability<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Damage to the environment<sup>[\[3\]](#cite_note-Clifton-3)</sup>

<a href="//en.wikipedia.org/wiki/File:Event_Tree_Diagram.JPG" class="image"><img src="//upload.wikimedia.org/wikipedia/commons/thumb/0/07/Event_Tree_Diagram.JPG/220px-Event_Tree_Diagram.JPG" class="thumbimage" srcset="//upload.wikimedia.org/wikipedia/commons/thumb/0/07/Event_Tree_Diagram.JPG/330px-Event_Tree_Diagram.JPG 1.5x, //upload.wikimedia.org/wikipedia/commons/thumb/0/07/Event_Tree_Diagram.JPG/440px-Event_Tree_Diagram.JPG 2x" width="220" height="167" /></a>
<a href="//en.wikipedia.org/wiki/File:Event_Tree_Diagram.JPG" class="internal" title="Enlarge"></a>

Event tree diagram example

<span id="Methodology" class="mw-headline">Methodology</span>
-------------------------------------------------------------

The overall goal of event tree analysis is to determine the probability of possible negative outcomes that can cause harm and result from the chosen initiating event. It is necessary to use detailed information about a system to understand intermediate events, accident scenarios, and initiating events to construct the event tree diagram. The event tree begins with the initiating event where consequences of this event follow in a binary (success/failure) manner. Each event creates a path in which a series of successes or failures will occur where the overall probability of occurrence for that path can be calculated. The probabilities of failures for intermediate events can be calculated using [fault tree analysis](//en.wikipedia.org/wiki/Fault_tree_analysis "Fault tree analysis") and the probability of success can be calculated from 1 = probability of success(ps) + probability of failure (pf).<sup>[\[3\]](#cite_note-Clifton-3)</sup> For example, in the equation 1 = (ps) + (pf) if we know that pf=.1 from fault tree analysis then through simple algebra we can solve for ps where ps = (1) - (pf) then we would have ps = (1) - (.1) and ps=.9.

The event tree diagram models all possible pathways from the initiating event. The initiating event starts at the left side as a horizontal line that branches vertically. the vertical branch is representative of the success/failure of the initiating event. At the end of the vertical branch a horizontal line is drawn on each the top and the bottom representing the success or failure of the first event where a description (usually success or failure) is written with a tag that represents the path such as 1s where s is a success and 1 is the event number similarly with 1f where 1 is the event number and f denotes a failure (see attached diagram). This process continues until the end state is reached. When the event tree diagram has reached the end state for all pathways the outcome probability equation is written.<sup>[\[1\]](#cite_note-Clemments_1-1)[\[3\]](#cite_note-Clifton-3)</sup>

Steps to perform an event tree analysis:<sup>[\[1\]](#cite_note-Clemments_1-1)[\[3\]](#cite_note-Clifton-3)</sup>

1.  **Define the system:** Define what needs to be involved or where to draw the boundaries.
2.  **Identify the accident scenarios:** Perform a system assessment to find hazards or accident scenarios within the system design.
3.  **Identify the initiating events:** Use a [hazard analysis](//en.wikipedia.org/wiki/Hazard_analysis "Hazard analysis") to define initiating events.
4.  **Identify intermediate events:** Identify <a href="//en.wikipedia.org/wiki/Countermeasures" class="mw-redirect" title="Countermeasures">countermeasures</a> associated with the specific scenario.
5.  **Build the event tree diagram**
6.  **Obtain event failure probabilities:** If the failure probability can not be obtained use [fault tree analysis](//en.wikipedia.org/wiki/Fault_tree_analysis "Fault tree analysis") to calculate it.
7.  **Identify the outcome risk:** Calculate the overall probability of the event paths and determine the [risk](//en.wikipedia.org/wiki/Risk "Risk").
8.  **Evaluate the outcome risk:** Evaluate the [risk](//en.wikipedia.org/wiki/Risk "Risk") of each path and determine its acceptability.
9.  **Recommend corrective action:** If the outcome [risk](//en.wikipedia.org/wiki/Risk "Risk") of a path is not acceptable develop design changes that change the [risk](//en.wikipedia.org/wiki/Risk "Risk").
10. **Document the ETA:** Document the entire process on the event tree diagrams and update for new information as needed.

<span id="Mathematical_concepts" class="mw-headline">Mathematical concepts</span>
---------------------------------------------------------------------------------

1 = (probability of success) + (probability of failure)

The probability of success can be derived from the probability of failure.

Overall path probability = (probability of event 1) X (probability of event 2) X (probability of event n....)

<span id="In_risk_analysis" class="mw-headline">In risk analysis</span>
-----------------------------------------------------------------------

Event tree analysis can be used in risk assessment by determining the probability that is used to determine the risk when multiplied by the hazard of the event. Event Tree Analysis is a tool that makes easy to see what pathway is creating the greatest probability of failure for a specific system. It is common to find single point failures that do not have any intervening events between the initiating event and a failure. With Event Tree Analysis single point failure can be targeted to include an intervening step that will reduce the overall probability of failure and thus reducing the risk of the system. The idea of adding an intervening event can happen anywhere in the system for any pathway that generates too great of a risk, the added intermediate event can reduce the probability and thus reduce the risk.

<span id="Advantages" class="mw-headline">Advantages</span>
-----------------------------------------------------------

-   Enables the assessment of multiple, co-existing faults and failures<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Functions simultaneously in cases of failure and success<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   No need to anticipate end events<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Areas of single point failure, system vulnerability, and low payoff countermeasures may be identified and assessed to deploy resources properly<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   paths in a system that lead to a failure can be identified and traced to display ineffective countermeasures.<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Work can be computerized<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Can be performed on various levels of details<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Visual cause and effect relationship<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Relatively easy to learn and execute<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Models complex systems into an understandable manner<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Follows fault paths across system boundaries<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Combines hardware, software, environment, and human interaction<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Permits probability assessment<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Commercial software is available<sup>[\[3\]](#cite_note-Clifton-3)</sup>

<span id="Limitations" class="mw-headline">Limitations</span>
-------------------------------------------------------------

-   Addresses only one initiating event at a time.<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   The initiating challenge must be identified by the analyst<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Pathways must be identified by the analyst<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Level of loss for each pathway may not be distinguishable without further analysis<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Success or failure probabilities are difficult to find.<sup>[\[1\]](#cite_note-Clemments_1-1)</sup>
-   Can overlook subtle system differences<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Partial successes/failures are not distinguishable<sup>[\[3\]](#cite_note-Clifton-3)</sup>
-   Requires an analyst with practical training and experience<sup>[\[3\]](#cite_note-Clifton-3)</sup>

<span id="Software" class="mw-headline">Software</span>
-------------------------------------------------------

Though ETA can be relatively simple, software can be used for more complex systems to build the diagram and perform calculations more quickly with reduction of human errors in the process. There are many types of software available to assist in conducting an ETA. The software available is generally not available from your local store but easily found with an online search. In nuclear industry, RiskSpectrum PSA software is widely used which has both event tree analysis and fault tree analysis.

<span id="References" class="mw-headline">References</span>
-----------------------------------------------------------

1.  

    <span class="mw-cite-backlink">^ [<sup>***a***</sup>](#cite_ref-Clemments_1_1-0) [<sup>***b***</sup>](#cite_ref-Clemments_1_1-1) [<sup>***c***</sup>](#cite_ref-Clemments_1_1-2) [<sup>***d***</sup>](#cite_ref-Clemments_1_1-3) [<sup>***e***</sup>](#cite_ref-Clemments_1_1-4) [<sup>***f***</sup>](#cite_ref-Clemments_1_1-5) [<sup>***g***</sup>](#cite_ref-Clemments_1_1-6) [<sup>***h***</sup>](#cite_ref-Clemments_1_1-7) [<sup>***i***</sup>](#cite_ref-Clemments_1_1-8) [<sup>***j***</sup>](#cite_ref-Clemments_1_1-9) [<sup>***k***</sup>](#cite_ref-Clemments_1_1-10) [<sup>***l***</sup>](#cite_ref-Clemments_1_1-11) [<sup>***m***</sup>](#cite_ref-Clemments_1_1-12) [<sup>***n***</sup>](#cite_ref-Clemments_1_1-13)</span> <span class="reference-text">Clemens, P.L.; Rodney J. Simmons (March 1998). "System Safety and Risk Management". *NIOSH Instructional Module, A guide for Engineering Educators*. Cincinnati,OH: National Institute for Occupational Safety and Health: IX–3 – IX–7.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AEvent+tree+analysis&amp;rft.atitle=System+Safety+and+Risk+Management&amp;rft.aufirst=P.L.&amp;rft.aulast=Clemens&amp;rft.au=Rodney+J.+Simmons&amp;rft.date=1998-03&amp;rft.genre=article&amp;rft.jtitle=NIOSH+Instructional+Module%2C+A+guide+for+Engineering+Educators&amp;rft.pages=IX-3+-+IX-7&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
2.  

    <span class="mw-cite-backlink">^ [<sup>***a***</sup>](#cite_ref-wang69_2-0) [<sup>***b***</sup>](#cite_ref-wang69_2-1)</span> <span class="reference-text">Wang, John *et al.* (2000). *<a href="https://books.google.com/books?id=x4Ft7H_2Ik0C&amp;pg=PA69" class="external text">What Every Engineer Should Know About Risk Engineering and Management, <em>p. 69.</em></a>*, p. 69, at [Google Books](//en.wikipedia.org/wiki/Google_Books "Google Books")</span>
3.  

    <span class="mw-cite-backlink">^ [<sup>***a***</sup>](#cite_ref-Clifton_3-0) [<sup>***b***</sup>](#cite_ref-Clifton_3-1) [<sup>***c***</sup>](#cite_ref-Clifton_3-2) [<sup>***d***</sup>](#cite_ref-Clifton_3-3) [<sup>***e***</sup>](#cite_ref-Clifton_3-4) [<sup>***f***</sup>](#cite_ref-Clifton_3-5) [<sup>***g***</sup>](#cite_ref-Clifton_3-6) [<sup>***h***</sup>](#cite_ref-Clifton_3-7) [<sup>***i***</sup>](#cite_ref-Clifton_3-8) [<sup>***j***</sup>](#cite_ref-Clifton_3-9) [<sup>***k***</sup>](#cite_ref-Clifton_3-10) [<sup>***l***</sup>](#cite_ref-Clifton_3-11) [<sup>***m***</sup>](#cite_ref-Clifton_3-12) [<sup>***n***</sup>](#cite_ref-Clifton_3-13) [<sup>***o***</sup>](#cite_ref-Clifton_3-14) [<sup>***p***</sup>](#cite_ref-Clifton_3-15) [<sup>***q***</sup>](#cite_ref-Clifton_3-16) [<sup>***r***</sup>](#cite_ref-Clifton_3-17) [<sup>***s***</sup>](#cite_ref-Clifton_3-18) [<sup>***t***</sup>](#cite_ref-Clifton_3-19) [<sup>***u***</sup>](#cite_ref-Clifton_3-20) [<sup>***v***</sup>](#cite_ref-Clifton_3-21) [<sup>***w***</sup>](#cite_ref-Clifton_3-22) [<sup>***x***</sup>](#cite_ref-Clifton_3-23) [<sup>***y***</sup>](#cite_ref-Clifton_3-24)</span> <span class="reference-text">Ericson, Clifton A. (2005). *Hazard Analysis Techniques for System Safety*. John Wiley & Sons, Inc.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AEvent+tree+analysis&amp;rft.aufirst=Clifton+A.&amp;rft.aulast=Ericson&amp;rft.btitle=Hazard+Analysis+Techniques+for+System+Safety&amp;rft.date=2005&amp;rft.genre=book&amp;rft.pub=John+Wiley+%26+Sons%2C+Inc.&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
4.  

    <span class="mw-cite-backlink">**[^](#cite_ref-Eun-Soo_4-0)**</span> <span class="reference-text">Hong, Eun-Soo; In-Mo Lee; Hee-Soon Shin; Seok-Woo Nam; Jung-Sik Kong (2009). "Quantitative risk evaluation based on event tree analysis technique: Application to the design of shield TBM". *Tunneling and Underground Space Technology*. **24** (3): 269–277. [doi](//en.wikipedia.org/wiki/Digital_object_identifier "Digital object identifier"):<a href="//doi.org/10.1016%2Fj.tust.2008.09.004" class="external text">10.1016/j.tust.2008.09.004</a>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3AEvent+tree+analysis&amp;rft.atitle=Quantitative+risk+evaluation+based+on+event+tree+analysis+technique%3A+Application+to+the+design+of+shield+TBM&amp;rft.aufirst=Eun-Soo&amp;rft.au=Hee-Soon+Shin&amp;rft.au=In-Mo+Lee&amp;rft.au=Jung-Sik+Kong&amp;rft.aulast=Hong&amp;rft.au=Seok-Woo+Nam&amp;rft.date=2009&amp;rft.genre=article&amp;rft_id=info%3Adoi%2F10.1016%2Fj.tust.2008.09.004&amp;rft.issue=3&amp;rft.jtitle=Tunneling+and+Underground+Space+Technology&amp;rft.pages=269-277&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.volume=24"><span style="display:none;"> </span></span></span>

