+++
title = "Technical details of Netflix"
date = "2015-12-14T16:46:25"
source = "https://en.wikipedia.org/wiki/Technical_details_of_Netflix"
categories = [ "pets", "work" ]
tags = [ "green", "yellow", "indigo", "blue", "grey", "violet" ]

+++

**[Netflix](//en.wikipedia.org/wiki/Netflix "Netflix")** is an American-based company that offers a service for streaming movies and TV series over the [Internet](//en.wikipedia.org/wiki/Internet "Internet"). Several technical development efforts were required to provide this service.

Contents
--------

-   [<span class="tocnumber">1</span> <span class="toctext">Streaming</span>](#Streaming)
-   [<span class="tocnumber">2</span> <span class="toctext">Netflix API</span>](#Netflix_API)
-   [<span class="tocnumber">3</span> <span class="toctext">Information technology</span>](#Information_technology)
-   [<span class="tocnumber">4</span> <span class="toctext">Open Connect</span>](#Open_Connect)
-   [<span class="tocnumber">5</span> <span class="toctext">References</span>](#References)

<span id="Streaming" class="mw-headline">Streaming</span>
---------------------------------------------------------

Initial [DVD](//en.wikipedia.org/wiki/DVD "DVD") discs sent to customers via US mail often received criticisms of being scratched and unable to fully play the rented movie. The popularity of Netflix dramatically increased with the addition of streaming through an online queue. This led to the majority of Netflix users reliably streaming movies and television shows rather than receiving physical DVD discs by mail.

Initially streaming starting in 2007 solely using [Microsoft](//en.wikipedia.org/wiki/Microsoft "Microsoft") technologies and codecs such as [VC-1](//en.wikipedia.org/wiki/VC-1 "VC-1") for video and [Windows Media Audio](//en.wikipedia.org/wiki/Windows_Media_Audio "Windows Media Audio") (WMA) for audio, the rapid expansion and diversity of Netflix-capable devices have necessitated encoding into many different formats – including <a href="//en.wikipedia.org/wiki/H.264" class="mw-redirect" title="H.264">H.264</a> (AVC), VC-1, [H.263](//en.wikipedia.org/wiki/H.263 "H.263") and [H.265 (HEVC)](//en.wikipedia.org/wiki/High_Efficiency_Video_Coding "High Efficiency Video Coding") for video, and [Dolby Digital](//en.wikipedia.org/wiki/Dolby_Digital "Dolby Digital"), [Dolby Digital Plus](//en.wikipedia.org/wiki/Dolby_Digital_Plus "Dolby Digital Plus"), [Advanced Audio Coding](//en.wikipedia.org/wiki/Advanced_Audio_Coding "Advanced Audio Coding") (AAC) and <a href="//en.wikipedia.org/wiki/Ogg_Vorbis" class="mw-redirect" title="Ogg Vorbis">Ogg Vorbis</a> for audio.<sup>[\[1\]](#cite_note-history-1)</sup> According to Netflix, the vast number of codec and bitrate combinations can mean having to encode the same title 120 different times before it can be delivered to all streaming platforms.<sup>[\[2\]](#cite_note-2)</sup>

Netflix uses [adaptive bitrate streaming](//en.wikipedia.org/wiki/Adaptive_bitrate_streaming "Adaptive bitrate streaming") technology to adjust the video and audio quality to match a customer's broadband connection speed and realtime network conditions.

In 2015, [BT](//en.wikipedia.org/wiki/BT_Group "BT Group")'s [YouView](//en.wikipedia.org/wiki/YouView "YouView") launched [Ultra HD](//en.wikipedia.org/wiki/Ultra-high-definition_television "Ultra-high-definition television") channels and a 4K box to watch it on in the UK.<sup>[\[3\]](#cite_note-3)</sup> As of December 2015, Netflix's 4K catalogue can be watched on BT's Ultra HD box. In order to stream the Ultra HD content, users need the top-tier subscription option.<sup>[\[4\]](#cite_note-4)</sup>

Netflix provides users the ability to choose their download rates quality of video on its website.

<span id="Netflix_API" class="mw-headline">Netflix API</span>
-------------------------------------------------------------

On October 1, 2008, Netflix offered access to its service via a public [application programming interface](//en.wikipedia.org/wiki/Application_programming_interface "Application programming interface") (API).<sup>[\[5\]](#cite_note-5)</sup> The Netflix API allows access to data for all Netflix titles as well as access on a user's behalf to manage his or her movie queue. The API was free and allowed commercial use.<sup>[\[6\]](#cite_note-6)</sup> A developer network included a forum for asking and answering questions.<sup>[\[7\]](#cite_note-HackingNetflix-7)</sup>

Examples of using the service included [Rotten Tomatoes](//en.wikipedia.org/wiki/Rotten_Tomatoes "Rotten Tomatoes") and *The New York Times*, which allow users to click to add titles to their Netflix queue or begin watching on "Watch Instantly" from their pages,<sup>[\[7\]](#cite_note-HackingNetflix-7)</sup> and [Jinni](//en.wikipedia.org/wiki/Jinni_(search_engine) "Jinni (search engine)"), which enabled one to search within Watch Instantly and imported some user information such as reviews.<sup>[\[8\]](#cite_note-8)</sup>

The API allowed developers to release Netflix applications for mobile devices. For example, on November 16, 2009, Netflix released an official <a href="//en.wikipedia.org/wiki/Nokia_phone" class="mw-redirect" title="Nokia phone">Nokia</a> app that allowed some trailer streaming,<sup>[\[9\]](#cite_note-9)</sup> and on August 26, 2010, Netflix released an official iPhone app.<sup>[\[10\]](#cite_note-10)</sup> However, in June 2012, Netflix began to cut back the availability of its public API.<sup>[\[11\]](#cite_note-11)</sup> The company instead focused on a small number of known partners using private interfaces, since most of the traffic came from those private interfaces.<sup>[\[12\]](#cite_note-12)</sup> In June 2014, Netflix announced that they would be retiring the public API. This became effective November 14, 2014.<sup>[\[13\]](#cite_note-13)</sup> Netflix then partnered with the developers of eight services deemed to have been the most valuable, including Instant Watcher, Fanhattan, Yidio, and Nextguide.<sup>[\[14\]](#cite_note-14)</sup>

<span id="Information_technology" class="mw-headline">Information technology</span>
-----------------------------------------------------------------------------------

In 2010, Netflix moved to using <a href="//en.wikipedia.org/wiki/Amazon_EC2" class="mw-redirect" title="Amazon EC2">Amazon EC2</a> for its [information technology](//en.wikipedia.org/wiki/Information_technology "Information technology") (IT) resources. Master copies of digital films from <a href="//en.wikipedia.org/wiki/Movie_studio" class="mw-redirect" title="Movie studio">movie studios</a> are stored on [Amazon S3](//en.wikipedia.org/wiki/Amazon_S3 "Amazon S3"), and each film is encoded into over 50 different versions based on video resolution and audio quality using machines on the [cloud](//en.wikipedia.org/wiki/Cloud_computing "Cloud computing"). In total, Netflix has over 1 [petabyte](//en.wikipedia.org/wiki/Petabyte "Petabyte") of data stored on Amazon,<sup>\[*[<span title="The time period mentioned near this tag is ambiguous. (September 2016)">when?</span>](//en.wikipedia.org/wiki/Wikipedia:Manual_of_Style/Dates_and_numbers#Chronological_items "Wikipedia:Manual of Style/Dates and numbers")*\]</sup> and the data is sent to [content delivery networks](//en.wikipedia.org/wiki/Content_delivery_network "Content delivery network") (including [Akamai Technologies](//en.wikipedia.org/wiki/Akamai_Technologies "Akamai Technologies"), [Limelight Networks](//en.wikipedia.org/wiki/Limelight_Networks "Limelight Networks") and [Level 3 Communications](//en.wikipedia.org/wiki/Level_3_Communications "Level 3 Communications")) that feed the content to local [ISPs](//en.wikipedia.org/wiki/Internet_service_provider "Internet service provider"). Netflix uses a number of pieces of [open-source software](//en.wikipedia.org/wiki/Open-source_software "Open-source software") in its <a href="//en.wikipedia.org/wiki/Backend_as_a_service" class="mw-redirect" title="Backend as a service">backend</a>, including [Java](//en.wikipedia.org/wiki/Java_(software_platform) "Java (software platform)"), [MySQL](//en.wikipedia.org/wiki/MySQL "MySQL"), [Gluster](//en.wikipedia.org/wiki/Gluster "Gluster"), [Apache Tomcat](//en.wikipedia.org/wiki/Apache_Tomcat "Apache Tomcat"), [Hive](//en.wikipedia.org/wiki/Apache_Hive "Apache Hive"), Chukwa, [Cassandra](//en.wikipedia.org/wiki/Apache_Cassandra "Apache Cassandra") and [Hadoop](//en.wikipedia.org/wiki/Apache_Hadoop "Apache Hadoop").<sup>[\[15\]](#cite_note-15)</sup>

In June, 2012, a storm in the Eastern US caused power outages in a major Amazon data center. This caused a three-hour downtime in Netflix services, and resulted in some improvements to the Netflix recovery software.<sup>[\[16\]](#cite_note-16)</sup> Another outage was experienced on December 24, 2012.<sup>[\[17\]](#cite_note-17)</sup>

Netflix developed several technologies to help manage its IT systems, an area known as [DevOps](//en.wikipedia.org/wiki/DevOps "DevOps"). One tool is called the "simian army", which includes the "chaos monkey".<sup>[\[18\]](#cite_note-18)</sup> By intentionally creating different failures, the ability to survive them can be tested under controlled conditions before they affect customers. The technology is claimed under at least one patent, filed in 2010 with inventors Gregory S. Orzell and Yury Izrailevsky.<sup>[\[19\]](#cite_note-19)</sup> Similar approaches were taken in the GameDay software by [Jesse Robbins](//en.wikipedia.org/wiki/Jesse_Robbins "Jesse Robbins") at [Amazon.com](//en.wikipedia.org/wiki/Amazon.com "Amazon.com"), "DIRT" created by at [Google](//en.wikipedia.org/wiki/Google "Google"), and others.<sup>[\[20\]](#cite_note-20)</sup> <sup>[\[21\]](#cite_note-21)</sup> The related software was made available on [GitHub](//en.wikipedia.org/wiki/GitHub "GitHub") in 2012.<sup>[\[22\]](#cite_note-22)</sup> This approach has been used for case studies,<sup>[\[23\]](#cite_note-23)</sup> and as the title of a 2016 memoir on a life in [Silicon Valley](//en.wikipedia.org/wiki/Silicon_Valley "Silicon Valley"), *[Chaos Monkeys](//en.wikipedia.org/wiki/Chaos_Monkeys "Chaos Monkeys")*.<sup>[\[24\]](#cite_note-24)[\[25\]](#cite_note-25)</sup>

<span id="Open_Connect" class="mw-headline">Open Connect</span>
---------------------------------------------------------------

Netflix settlement freely [peers](//en.wikipedia.org/wiki/Peering "Peering") with [Internet service providers](//en.wikipedia.org/wiki/Internet_service_provider "Internet service provider") (ISPs) directly and at common [Internet exchange points](//en.wikipedia.org/wiki/Internet_exchange_point "Internet exchange point"). In June 2012, a custom [content delivery network](//en.wikipedia.org/wiki/Content_delivery_network "Content delivery network") called Open Connect was announced.<sup>[\[26\]](#cite_note-26)</sup> For larger ISPs that have over 100,000 subscribers Netflix offers free *Netflix Open Connect* <a href="//en.wikipedia.org/wiki/Server_appliance" class="mw-redirect" title="Server appliance">server appliances</a> that cache Netflix content within the ISPs' [data centers](//en.wikipedia.org/wiki/Data_center "Data center") or networks to further reduce [Internet transit](//en.wikipedia.org/wiki/Internet_transit "Internet transit") costs.<sup>[\[27\]](#cite_note-27)[\[28\]](#cite_note-28)</sup> The Open Connect appliances are purpose-built servers that focus on low power and high storage density, and run the [FreeBSD](//en.wikipedia.org/wiki/FreeBSD "FreeBSD") operating system, [nginx](//en.wikipedia.org/wiki/Nginx "Nginx") and the [Bird Internet routing daemon](//en.wikipedia.org/wiki/Bird_Internet_routing_daemon "Bird Internet routing daemon").<sup>[\[29\]](#cite_note-cdn2013-29)</sup> By August 2016, Netflix closed its last physical data center, but continued to develop its Open Connect technology.<sup>[\[30\]](#cite_note-30)</sup>

A 2016 study at the [University of London](//en.wikipedia.org/wiki/University_of_London "University of London") detected 233 individual locations over six continents, with the largest amount of traffic in the USA, followed by Mexico.<sup>[\[31\]](#cite_note-31)[\[32\]](#cite_note-32)</sup>

<span id="References" class="mw-headline">References</span>
-----------------------------------------------------------

1.  

    <span class="mw-cite-backlink">**[^](#cite_ref-history_1-0)**</span> <span class="reference-text">David Ronca (May 31, 2013). <a href="http://blog.streamingmedia.com/wp-content/uploads/2013/07/2013SMEast-C101.pdf" class="external text">&quot;A Brief History of Netflix Streaming&quot;</a> <span style="font-size:85%;">(PDF)</span><span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=David+Ronca&amp;rft.btitle=A+Brief+History+of+Netflix+Streaming&amp;rft.date=2013-05-31&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fblog.streamingmedia.com%2Fwp-content%2Fuploads%2F2013%2F07%2F2013SMEast-C101.pdf&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
2.  

    <span class="mw-cite-backlink">**[^](#cite_ref-2)**</span> <span class="reference-text">McEntee, Kevin (December 17, 2012). <a href="http://techblog.netflix.com/2012/12/complexity-in-digital-supply-chain.html" class="external text">&quot;Complexity In The Digital Supply Chain&quot;</a>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=McEntee%2C+Kevin&amp;rft.btitle=Complexity+In+The+Digital+Supply+Chain&amp;rft.date=2012-12-17&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Ftechblog.netflix.com%2F2012%2F12%2Fcomplexity-in-digital-supply-chain.html&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
3.  

    <span class="mw-cite-backlink">**[^](#cite_ref-3)**</span> <span class="reference-text"><a href="http://www.pocket-lint.com/news/136230-4k-netflix-comes-to-youview-thanks-to-bt-watch-ultra-hd-shows-and-films-on-your-box" class="external text">&quot;4K Netflix comes to YouView thanks to BT: Watch Ultra HD shows and films on your box – Pocket-lint&quot;</a>. *www.pocket-lint.com*<span class="reference-accessdate">. Retrieved <span class="nowrap">2015-12-21</span></span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=4K+Netflix+comes+to+YouView+thanks+to+BT%3A+Watch+Ultra+HD+shows+and+films+on+your+box+%E2%80%93+Pocket-lint&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.pocket-lint.com%2Fnews%2F136230-4k-netflix-comes-to-youview-thanks-to-bt-watch-ultra-hd-shows-and-films-on-your-box&amp;rft.jtitle=www.pocket-lint.com&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
4.  

    <span class="mw-cite-backlink">**[^](#cite_ref-4)**</span> <span class="reference-text"><a href="http://www.engadget.com/2015/12/21/bt-box-netflix-4k/" class="external text">&quot;BT's Ultra HD box can now stream Netflix in 4K&quot;</a>. *Engadget*<span class="reference-accessdate">. Retrieved <span class="nowrap">2015-12-21</span></span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=BT%27s+Ultra+HD+box+can+now+stream+Netflix+in+4K&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.engadget.com%2F2015%2F12%2F21%2Fbt-box-netflix-4k%2F&amp;rft.jtitle=Engadget&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
5.  

    <span class="mw-cite-backlink">**[^](#cite_ref-5)**</span> <span class="reference-text"><a href="http://www.readwriteweb.com/archives/netflix_api_launches_tomorrow.php" class="external text">&quot;Netflix API Launches Tomorrow&quot;</a>. ReadWriteWeb<span class="reference-accessdate">. Retrieved <span class="nowrap">September 30,</span> 2008</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Netflix+API+Launches+Tomorrow&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.readwriteweb.com%2Farchives%2Fnetflix_api_launches_tomorrow.php&amp;rft.pub=ReadWriteWeb&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
6.  

    <span class="mw-cite-backlink">**[^](#cite_ref-6)**</span> <span class="reference-text"><a href="http://www.mashery.com/customers/netflix" class="external text">&quot;Netflix API Management Solution&quot;</a>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Netflix+API+Management+Solution&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.mashery.com%2Fcustomers%2Fnetflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
7.  

    <span class="mw-cite-backlink">^ [<sup>***a***</sup>](#cite_ref-HackingNetflix_7-0) [<sup>***b***</sup>](#cite_ref-HackingNetflix_7-1)</span> <span class="reference-text"><a href="http://www.hackingnetflix.com/2009/02/ny-times-rotten-tomatoes-add-netflix-add-play-links.html" class="external text">&quot;New York Times &amp; Rotten Tomatoes Add Netflix &quot;Add&quot; &amp; &quot;Watch&quot; Links&quot;</a>. HackingNetflix<span class="reference-accessdate">. Retrieved <span class="nowrap">February 20,</span> 2009</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=New+York+Times+%26+Rotten+Tomatoes+Add+Netflix+%22Add%22+%26+%22Watch%22+Links&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.hackingnetflix.com%2F2009%2F02%2Fny-times-rotten-tomatoes-add-netflix-add-play-links.html&amp;rft.pub=HackingNetflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
8.  

    <span class="mw-cite-backlink">**[^](#cite_ref-8)**</span> <span class="reference-text"><a href="http://news.cnet.com/8301-17939_109-10199106-2.html" class="external text">&quot;Jinni Searches Netflix better than Netflix&quot;</a>. CNET<span class="reference-accessdate">. Retrieved <span class="nowrap">March 18,</span> 2009</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Jinni+Searches+Netflix+better+than+Netflix&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fnews.cnet.com%2F8301-17939_109-10199106-2.html&amp;rft.pub=CNET&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
9.  

    <span class="mw-cite-backlink">**[^](#cite_ref-9)**</span> <span class="reference-text">Hart, Michael (November 16, 2009). <a href="http://blog.netflix.com/2009/11/netflix-for-nokia-phones.html" class="external text">&quot;Netflix for Nokia Phones&quot;</a>. Netflix<span class="reference-accessdate">. Retrieved <span class="nowrap">April 2,</span> 2011</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.aufirst=Michael&amp;rft.aulast=Hart&amp;rft.btitle=Netflix+for+Nokia+Phones&amp;rft.date=2009-11-16&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fblog.netflix.com%2F2009%2F11%2Fnetflix-for-nokia-phones.html&amp;rft.pub=Netflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
10. 

    <span class="mw-cite-backlink">**[^](#cite_ref-10)**</span> <span class="reference-text"><a href="http://blog.netflix.com/2010/04/netflix-on-iphone.html" class="external text">&quot;Netflix on iPhone?&quot;</a>. Netflix. April 2, 2010<span class="reference-accessdate">. Retrieved <span class="nowrap">July 19,</span> 2010</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Netflix+on+iPhone%3F&amp;rft.date=2010-04-02&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fblog.netflix.com%2F2010%2F04%2Fnetflix-on-iphone.html&amp;rft.pub=Netflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
11. 

    <span class="mw-cite-backlink">**[^](#cite_ref-11)**</span> <span class="reference-text"><a href="http://developer.netflix.com/blog/read/Upcoming_Changes_to_the_Netflix_API_Program" class="external text">&quot;Upcoming Changes to the Netflix API Program&quot;</a>. Netflix. June 15, 2012<span class="reference-accessdate">. Retrieved <span class="nowrap">June 21,</span> 2012</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Upcoming+Changes+to+the+Netflix+API+Program&amp;rft.date=2012-06-15&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fdeveloper.netflix.com%2Fblog%2Fread%2FUpcoming_Changes_to_the_Netflix_API_Program&amp;rft.pub=Netflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
12. 

    <span class="mw-cite-backlink">**[^](#cite_ref-12)**</span> <span class="reference-text">Daniel Jacobson and Sangeeta Narayanan (July 24, 2014). <a href="http://www.slideshare.net/danieljacobson/top-10-lessons-learned-from-the-netflix-api-oscon-2014" class="external text">&quot;Netflix API: Top 10 Lessons Learned (so far)&quot;</a><span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=Daniel+Jacobson+and+Sangeeta+Narayanan&amp;rft.btitle=Netflix+API%3A+Top+10+Lessons+Learned+%28so+far%29&amp;rft.date=2014-07-24&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.slideshare.net%2Fdanieljacobson%2Ftop-10-lessons-learned-from-the-netflix-api-oscon-2014&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
13. 

    <span class="mw-cite-backlink">**[^](#cite_ref-13)**</span> <span class="reference-text">Janko Roettgers (November 14, 2014). <a href="https://gigaom.com/2014/11/14/netflix-is-shutting-down-its-public-api-today/" class="external text">&quot;Netflix is shutting down its public API today&quot;</a>. *GigaOm*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+is+shutting+down+its+public+API+today&amp;rft.au=Janko+Roettgers&amp;rft.date=2014-11-14&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Fgigaom.com%2F2014%2F11%2F14%2Fnetflix-is-shutting-down-its-public-api-today%2F&amp;rft.jtitle=GigaOm&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
14. 

    <span class="mw-cite-backlink">**[^](#cite_ref-14)**</span> <span class="reference-text">Jacobson, Daniel (June 13, 2014). <a href="http://developer.netflix.com/blog/read/Retiring_the_Netflix_Public_API" class="external text">&quot;Retiring the Netflix Public API&quot;</a>. Netflix<span class="reference-accessdate">. Retrieved <span class="nowrap">August 11,</span> 2014</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.aufirst=Daniel&amp;rft.aulast=Jacobson&amp;rft.btitle=Retiring+the+Netflix+Public+API&amp;rft.date=2014-06-13&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fdeveloper.netflix.com%2Fblog%2Fread%2FRetiring_the_Netflix_Public_API&amp;rft.pub=Netflix&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
15. 

    <span class="mw-cite-backlink">**[^](#cite_ref-15)**</span> <span class="reference-text"><a href="https://www.youtube.com/watch?v=Idu9OKnAOis" class="external text"><span class="plainlinks">OSCON Data 2011, Adrian Cockcroft, &quot;Data Flow at Netflix&quot;</span></a> on [YouTube](//en.wikipedia.org/wiki/YouTube "YouTube")</span>
16. 

    <span class="mw-cite-backlink">**[^](#cite_ref-16)**</span> <span class="reference-text">Yevgeniy Sverdlik (July 6, 2012). <a href="http://www.datacenterdynamics.com/content-tracks/colo-cloud/netflix-uncovers-its-own-system-faults-following-amazon-cloud-outage/66596.article" class="external text">&quot;Netflix uncovers its own system faults following Amazon cloud outage&quot;</a>. *Data Center Dynamics*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 15,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+uncovers+its+own+system+faults+following+Amazon+cloud+outage&amp;rft.au=Yevgeniy+Sverdlik&amp;rft.date=2012-07-06&amp;rft.genre=article&amp;rft_id=http%3A%2F%2Fwww.datacenterdynamics.com%2Fcontent-tracks%2Fcolo-cloud%2Fnetflix-uncovers-its-own-system-faults-following-amazon-cloud-outage%2F66596.article&amp;rft.jtitle=Data+Center+Dynamics&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
17. 

    <span class="mw-cite-backlink">**[^](#cite_ref-17)**</span> <span class="reference-text">Bryan Bishop (December 24, 2012). <a href="http://www.theverge.com/2012/12/24/3801978/netflix-streaming-down-on-some-devices-thanks-to-amazon-issues" class="external text">&quot;Netflix streaming down on some devices due to Amazon issues&quot;</a>. *The Verge*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 15,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+streaming+down+on+some+devices+due+to+Amazon+issues&amp;rft.au=Bryan+Bishop&amp;rft.date=2012-12-24&amp;rft.genre=article&amp;rft_id=http%3A%2F%2Fwww.theverge.com%2F2012%2F12%2F24%2F3801978%2Fnetflix-streaming-down-on-some-devices-thanks-to-amazon-issues&amp;rft.jtitle=The+Verge&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
18. 

    <span class="mw-cite-backlink">**[^](#cite_ref-18)**</span> <span class="reference-text"><a href="https://github.com/Netflix/SimianArmy/wiki" class="external text">&quot;What is Simian Army?&quot;</a>. *Git Hub*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=What+is+Simian+Army%3F&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Fgithub.com%2FNetflix%2FSimianArmy%2Fwiki&amp;rft.jtitle=Git+Hub&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
19. 

    <span class="mw-cite-backlink">**[^](#cite_ref-19)**</span> <span class="reference-text">Gregory S. Orzell and Yury Izrailevsky (September 20, 2010). <a href="https://www.google.com/patents/US20120072571" class="external text">&quot;Validating the resiliency of networked applications&quot;</a>. *US Patent US20120072571 A1*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Validating+the+resiliency+of+networked+applications&amp;rft.au=Gregory+S.+Orzell+and+Yury+Izrailevsky&amp;rft.date=2010-09-20&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Fwww.google.com%2Fpatents%2FUS20120072571&amp;rft.jtitle=US+Patent+US20120072571+A1&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span> Published March 22, 2012</span>
20. 

    <span class="mw-cite-backlink">**[^](#cite_ref-20)**</span> <span class="reference-text">[Tom Limoncelli](//en.wikipedia.org/wiki/Tom_Limoncelli "Tom Limoncelli"); [Jesse Robbins](//en.wikipedia.org/wiki/Jesse_Robbins "Jesse Robbins"); Kripa Krishnan; John Allspaw (September 12, 2012). <a href="http://queue.acm.org/detail.cfm?id=2371297" class="external text">&quot;Resilience Engineering: Learning to Embrace Failure&quot;</a>. *ACM Queue*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Resilience+Engineering%3A+Learning+to+Embrace+Failure&amp;rft.au=Jesse+Robbins&amp;rft.au=John+Allspaw&amp;rft.au=Kripa+Krishnan&amp;rft.au=Tom+Limoncelli&amp;rft.date=2012-09-12&amp;rft.genre=article&amp;rft_id=http%3A%2F%2Fqueue.acm.org%2Fdetail.cfm%3Fid%3D2371297&amp;rft.jtitle=ACM+Queue&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
21. 

    <span class="mw-cite-backlink">**[^](#cite_ref-21)**</span> <span class="reference-text">Paul Harris (May 1, 2015). <a href="https://blog.pivotal.io/pivotal-cloud-foundry/products/chaos-lemur-testing-high-availability-on-pivotal-cloud-foundry" class="external text">&quot;Chaos Lemur: Testing High Availability on Pivotal Cloud Foundry&quot;</a><span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=Paul+Harris&amp;rft.btitle=Chaos+Lemur%3A+Testing+High+Availability+on+Pivotal+Cloud+Foundry&amp;rft.date=2015-05-01&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Fblog.pivotal.io%2Fpivotal-cloud-foundry%2Fproducts%2Fchaos-lemur-testing-high-availability-on-pivotal-cloud-foundry&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
22. 

    <span class="mw-cite-backlink">**[^](#cite_ref-22)**</span> <span class="reference-text">Cory Bennett and Ariel Tseitlin (July 30, 2012). <a href="http://techblog.netflix.com/2012/07/chaos-monkey-released-into-wild.html" class="external text">&quot;Chaos Monkey Released Into The Wild&quot;</a>. *The Nteflix Tech Blog*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Chaos+Monkey+Released+Into+The+Wild&amp;rft.au=Cory+Bennett+and+Ariel+Tseitlin&amp;rft.date=2012-07-30&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Ftechblog.netflix.com%2F2012%2F07%2Fchaos-monkey-released-into-wild.html&amp;rft.jtitle=The+Nteflix+Tech+Blog&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
23. 

    <span class="mw-cite-backlink">**[^](#cite_ref-23)**</span> <span class="reference-text">C. Arron Cois (April 30, 2015). <a href="https://insights.sei.cmu.edu/devops/2015/04/devops-case-study-netflix-and-the-chaos-monkey.html" class="external text">&quot;DevOps Case Study: Netflix and the Chaos Monkey&quot;</a>. Software Engineering Institute<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=C.+Arron+Cois&amp;rft.btitle=DevOps+Case+Study%3A+Netflix+and+the+Chaos+Monkey&amp;rft.date=2015-04-30&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Finsights.sei.cmu.edu%2Fdevops%2F2015%2F04%2Fdevops-case-study-netflix-and-the-chaos-monkey.html&amp;rft.pub=Software+Engineering+Institute&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
24. 

    <span class="mw-cite-backlink">**[^](#cite_ref-24)**</span> <span class="reference-text">García Martínez. <a href="http://www.antoniogarciamartinez.com/chaos-monkeys/" class="external text">&quot;Chaos Monkeys&quot;</a>. *Blog*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Chaos+Monkeys&amp;rft.au=Garc%C3%ADa+Mart%C3%ADnez&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.antoniogarciamartinez.com%2Fchaos-monkeys%2F&amp;rft.jtitle=Blog&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
25. 

    <span class="mw-cite-backlink">**[^](#cite_ref-25)**</span> <span class="reference-text"><a href="http://go.bigswitch.com/rs/974-WXR-561/images/Chaos%20Monkey%20-%20OpenStack%20-%20Big%20Cloud%20Fabric.pdf" class="external text">&quot;Chaos Monkey and Neutron&quot;</a> <span style="font-size:85%;">(PDF)</span>. January 29, 2015<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.btitle=Chaos+Monkey+and+Neutron&amp;rft.date=2015-01-29&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fgo.bigswitch.com%2Frs%2F974-WXR-561%2Fimages%2FChaos%2520Monkey%2520-%2520OpenStack%2520-%2520Big%2520Cloud%2520Fabric.pdf&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
26. 

    <span class="mw-cite-backlink">**[^](#cite_ref-26)**</span> <span class="reference-text">Ryan Lawler (June 4, 2016). <a href="https://techcrunch.com/2012/06/04/netflix-open-connect/" class="external text">&quot;Netflix Rolls Out Its Own CDN: Open Connect&quot;</a>. *Tech Crunch*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+Rolls+Out+Its+Own+CDN%3A+Open+Connect&amp;rft.au=Ryan+Lawler&amp;rft.date=2016-06-04&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Ftechcrunch.com%2F2012%2F06%2F04%2Fnetflix-open-connect%2F&amp;rft.jtitle=Tech+Crunch&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
27. 

    <span class="mw-cite-backlink">**[^](#cite_ref-27)**</span> <span class="reference-text"><a href="https://www.netflix.com/openconnect" class="external text">&quot;Netflix Open Connect Content Delivery Network&quot;</a>. *netflix.com*<span class="reference-accessdate">. Retrieved <span class="nowrap">October 25,</span> 2014</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+Open+Connect+Content+Delivery+Network&amp;rft.genre=unknown&amp;rft_id=https%3A%2F%2Fwww.netflix.com%2Fopenconnect&amp;rft.jtitle=netflix.com&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
28. 

    <span class="mw-cite-backlink">**[^](#cite_ref-28)**</span> <span class="reference-text">Eric Savitz (June 5, 2012). <a href="http://www.forbes.com/sites/ericsavitz/2012/06/05/netflix-shifts-traffic-to-its-own-cdn-akamai-limelight-shrs-hit/" class="external text">&quot;Netflix Shifts Traffic To Its Own CDN; Akamai, Limelight Shrs Hit&quot;</a>. *Forbes*<span class="reference-accessdate">. Retrieved <span class="nowrap">October 25,</span> 2014</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+Shifts+Traffic+To+Its+Own+CDN%3B+Akamai%2C+Limelight+Shrs+Hit&amp;rft.au=Eric+Savitz&amp;rft.date=2012-06-05&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.forbes.com%2Fsites%2Fericsavitz%2F2012%2F06%2F05%2Fnetflix-shifts-traffic-to-its-own-cdn-akamai-limelight-shrs-hit%2F&amp;rft.jtitle=Forbes&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
29. 

    <span class="mw-cite-backlink">**[^](#cite_ref-cdn2013_29-0)**</span> <span class="reference-text"><a href="http://blog.streamingmedia.com/wp-content/uploads/2014/02/2013CDNSummit-Keynote-Netflix.pdf" class="external text">&quot;Netflix Content Delivery&quot;</a> <span style="font-size:85%;">(PDF)</span>. *Content Delivery Summit*. May 22, 2013<span class="reference-accessdate">. Retrieved <span class="nowrap">September 12,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix+Content+Delivery&amp;rft.date=2013-05-22&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fblog.streamingmedia.com%2Fwp-content%2Fuploads%2F2014%2F02%2F2013CDNSummit-Keynote-Netflix.pdf&amp;rft.jtitle=Content+Delivery+Summit&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
30. 

    <span class="mw-cite-backlink">**[^](#cite_ref-30)**</span> <span class="reference-text">Peter Judge (August 20, 2015). <a href="http://www.datacenterdynamics.com/content-tracks/colo-cloud/netflixs-data-centers-are-dead-long-live-the-cdn/94661.fullarticle" class="external text">&quot;Netflix's data centers are dead, long live the CDN!&quot;</a>. *Data Center Dynamics*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 15,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Netflix%27s+data+centers+are+dead%2C+long+live+the+CDN%21&amp;rft.au=Peter+Judge&amp;rft.date=2015-08-20&amp;rft.genre=article&amp;rft_id=http%3A%2F%2Fwww.datacenterdynamics.com%2Fcontent-tracks%2Fcolo-cloud%2Fnetflixs-data-centers-are-dead-long-live-the-cdn%2F94661.fullarticle&amp;rft.jtitle=Data+Center+Dynamics&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
31. 

    <span class="mw-cite-backlink">**[^](#cite_ref-31)**</span> <span class="reference-text">Richard Chirgwin (June 22, 2016). <a href="http://www.theregister.co.uk/2016/06/22/boffins_map_netflixs_open_connect_cdn/" class="external text">&quot;Boffins map Netflix's Open Connect CDN: Six continents, 233 locations, thousands of servers&quot;</a>. *The Register*<span class="reference-accessdate">. Retrieved <span class="nowrap">September 15,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.atitle=Boffins+map+Netflix%27s+Open+Connect+CDN%3A+Six+continents%2C+233+locations%2C+thousands+of+servers&amp;rft.au=Richard+Chirgwin&amp;rft.date=2016-06-22&amp;rft.genre=article&amp;rft_id=http%3A%2F%2Fwww.theregister.co.uk%2F2016%2F06%2F22%2Fboffins_map_netflixs_open_connect_cdn%2F&amp;rft.jtitle=The+Register&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
32. 

    <span class="mw-cite-backlink">**[^](#cite_ref-32)**</span> <span class="reference-text">Timm Böttger, Felix Cuadrado, Gareth Tyson, Ignacio Castro, Steve Uhlig (June 17, 2016). <a href="http://arxiv.org/abs/1606.05519" class="external text">&quot;Open Connect Everywhere: A Glimpse at the Internet Ecosystem through the Lens of the Netflix CDN&quot;</a>. ArXiv at Cornell University<span class="reference-accessdate">. Retrieved <span class="nowrap">September 15,</span> 2016</span>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ATechnical+details+of+Netflix&amp;rft.au=Timm+B%C3%B6ttger%2C+Felix+Cuadrado%2C+Gareth+Tyson%2C+Ignacio+Castro%2C+Steve+Uhlig&amp;rft.btitle=Open+Connect+Everywhere%3A+A+Glimpse+at+the+Internet+Ecosystem+through+the+Lens+of+the+Netflix+CDN&amp;rft.date=2016-06-17&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Farxiv.org%2Fabs%2F1606.05519&amp;rft.pub=ArXiv+at+Cornell+University&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span><span class="citation-comment" style="display:none; color:#33aa33; margin-left:0.3em">CS1 maint: Multiple names: authors list ([link](//en.wikipedia.org/wiki/Category:CS1_maint:_Multiple_names:_authors_list "Category:CS1 maint: Multiple names: authors list"))</span></span>

