+++
title = "Bare-metal server"
date = "2015-01-04T11:43:46"
source = "https://en.wikipedia.org/wiki/Bare-metal_server"
categories = [ "books", "music", "blog", "games", "work", "home", "movies" ]
tags = [ "indigo", "white" ]

+++

A **'bare-metal server'** is a descriptive term for a <a href="//en.wikipedia.org/wiki/Computer_server" class="mw-redirect" title="Computer server">computer server</a> to distinguish it from modern forms of [virtualization](//en.wikipedia.org/wiki/Virtual_machine "Virtual machine") and <a href="//en.wikipedia.org/wiki/Cloud_hosting" class="mw-redirect" title="Cloud hosting">cloud hosting</a>. It is defined as a 'single-tenant physical server'.<sup>[\[1\]](#cite_note-1)</sup>

Bare-metal servers have a single 'tenant'. They are not shared between customers. Each server may run any amount of work for the customer, or may have multiple simultaneous users, but they are dedicated entirely to the customer who is renting them. Unlike many servers in a <a href="//en.wikipedia.org/wiki/Data_centre" class="mw-redirect" title="Data centre">data centre</a>, they are not being shared between multiple customers.

Bare-metal servers are 'physical' servers. Each logical server offered for rental is a distinct physical piece of hardware that is a functional server on its own. They are not [virtual servers](//en.wikipedia.org/wiki/Virtual_machine "Virtual machine") running in multiple on shared hardware.

Contents
--------

-   [<span class="tocnumber">1</span> <span class="toctext">Development of virtualisation</span>](#Development_of_virtualisation)
-   [<span class="tocnumber">2</span> <span class="toctext">Bare-metal advocacy</span>](#Bare-metal_advocacy)
-   [<span class="tocnumber">3</span> <span class="toctext">Bare-metal cloud hosting</span>](#Bare-metal_cloud_hosting)
-   [<span class="tocnumber">4</span> <span class="toctext">See also</span>](#See_also)
-   [<span class="tocnumber">5</span> <span class="toctext">References</span>](#References)

<span id="Development_of_virtualisation" class="mw-headline">Development of virtualisation</span>
-------------------------------------------------------------------------------------------------

At one time, *all* servers were bare-metal servers. Servers were kept <a href="//en.wikipedia.org/wiki/On-premises_hosting" class="mw-redirect" title="On-premises hosting">on-premises</a> and often belonged to the organisation using and operating them. [Operating systems](//en.wikipedia.org/wiki/Operating_system "Operating system") developed very early on (early 1960s) to allow [time-sharing](//en.wikipedia.org/wiki/Time-sharing "Time-sharing"). Single large computers, [mainframes](//en.wikipedia.org/wiki/Mainframe_computer "Mainframe computer") or [minis](//en.wikipedia.org/wiki/Minicomputer "Minicomputer"), were commonly housed in centralised locations and their services shared through a [bureau](//en.wikipedia.org/wiki/Computer_bureau "Computer bureau"). The shift to cheap <a href="//en.wikipedia.org/wiki/PC_clone" class="mw-redirect" title="PC clone">commodity PCs</a> in the 1980s changed this as the market expanded, and most organisations, even the smallest, began to purchase or lease their own computers. Popular growth of the internet, and particularly the web, in the 1990s encouraged the practice of hosting in <a href="//en.wikipedia.org/wiki/Data_centre" class="mw-redirect" title="Data centre">data centres</a>, where many customers shared the facilities of single servers. Small web servers at this time often cost more for their connectivity than their hardware cost, encouraging this centralisation. <a href="//en.wikipedia.org/wiki/HTTP" class="mw-redirect" title="HTTP">HTTP 1.1</a>'s ability for [virtual hosting](//en.wikipedia.org/wiki/Virtual_hosting "Virtual hosting") also made it easy to co-host many web sites on the same [server](//en.wikipedia.org/wiki/Web_server "Web server").

From around 2000, or 2005 in commercially practical terms, interest grew in the use of [virtual servers](//en.wikipedia.org/wiki/Virtual_private_server "Virtual private server") and then <a href="//en.wikipedia.org/wiki/Cloud_hosting" class="mw-redirect" title="Cloud hosting">cloud hosting</a>, where <a href="//en.wikipedia.org/wiki/Infrastructure_as_a_Service" class="mw-redirect" title="Infrastructure as a Service">Infrastructure as a Service</a> made the computing *service* the <a href="//en.wikipedia.org/wiki/Fungible" class="mw-redirect" title="Fungible">fungible</a> commodity, rather than the server hardware. [Hypervisors](//en.wikipedia.org/wiki/Hypervisor "Hypervisor") were developed which could offer many [virtual machines](//en.wikipedia.org/wiki/Virtual_machine "Virtual machine") hosted on larger physical servers. The load pattern of multiple users has long been recognised as being smoother overall than individual users, so these virtual machines could make more efficient use of the physical hardware and its costs, whilst also appearing to have higher individual performance than a simple cost-share would suggest.

<span id="Bare-metal_advocacy" class="mw-headline">Bare-metal advocacy</span>
-----------------------------------------------------------------------------

Hypervisors provide secure isolation between tenants but there can still be a 'noisy neighbour effect'.<sup>[\[2\]](#cite_note-Internap-2)</sup> If a physical server is multi-tenanted, peaks of load from one tenant may consume enough machine resources to temporarily affect other tenants. As the tenants are otherwise isolated, it is also hard to manage or [load balance](//en.wikipedia.org/wiki/Load_balancing_(computing) "Load balancing (computing)") this. Bare-metal servers, and single tenancy, can avoid this. As, once again, server costs are dropping as a proportion of [total cost of ownership](//en.wikipedia.org/wiki/Total_cost_of_ownership "Total cost of ownership") against their administration overhead, the classic solution of 'throwing hardware at the problem' becomes viable again.

<span id="Bare-metal_cloud_hosting" class="mw-headline">Bare-metal cloud hosting</span>
---------------------------------------------------------------------------------------

> Bare-metal cloud servers do not run a hypervisor, are not virtualised -- but can still be delivered via a cloud-like service model.
>
> — <sup>[\[3\]](#cite_note-CWDN-3)</sup>

<a href="//en.wikipedia.org/wiki/Infrastructure_as_a_Service" class="mw-redirect" title="Infrastructure as a Service">Infrastructure as a Service</a>, particularly through [Infrastructure as Code](//en.wikipedia.org/wiki/Infrastructure_as_Code "Infrastructure as Code"), offers many advantages to make hosting conveniently manageable. Combining the features of both cloud hosting, and bare-metal servers, offers most of these, whilst still conveying the performance advantages.<sup>[\[3\]](#cite_note-CWDN-3)</sup>

<span id="See_also" class="mw-headline">See also</span>
-------------------------------------------------------

-   [On-premises software](//en.wikipedia.org/wiki/On-premises_software "On-premises software")

<span id="References" class="mw-headline">References</span>
-----------------------------------------------------------

1.  

    <span class="mw-cite-backlink">**[^](#cite_ref-1)**</span> <span class="reference-text">Reynaldo Mincov (July 25, 2014). <a href="http://www.thoughtsoncloud.com/2014/07/bare-metal-vs-virtual-servers-choice-right/" class="external text">&quot;Bare metal vs. virtual servers: Which choice is right for you?&quot;</a>. *Thoughts on Cloud*.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ABare-metal+server&amp;rft.atitle=Bare+metal+vs.+virtual+servers%3A+Which+choice+is+right+for+you%3F&amp;rft.au=Reynaldo+Mincov&amp;rft.date=2014-07-25&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.thoughtsoncloud.com%2F2014%2F07%2Fbare-metal-vs-virtual-servers-choice-right%2F&amp;rft.jtitle=Thoughts+on+Cloud&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>
2.  

    <span class="mw-cite-backlink">**[^](#cite_ref-Internap_2-0)**</span> <span class="reference-text">Eric Sarault (February 26, 2015). <a href="http://www.internap.com/2015/02/26/bare-metal-vs-hypervisor/" class="external text">&quot;Bare metal vs. hypervisor: The evolution of dedicated servers&quot;</a>.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ABare-metal+server&amp;rft.au=Eric+Sarault&amp;rft.btitle=Bare+metal+vs.+hypervisor%3A+The+evolution+of+dedicated+servers&amp;rft.date=2015-02-26&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.internap.com%2F2015%2F02%2F26%2Fbare-metal-vs-hypervisor%2F&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Abook"><span style="display:none;"> </span></span></span>
3.  

    <span class="mw-cite-backlink">^ [<sup>***a***</sup>](#cite_ref-CWDN_3-0) [<sup>***b***</sup>](#cite_ref-CWDN_3-1)</span> <span class="reference-text">Adrian Bridgwater (September 6, 2013). <a href="http://www.computerweekly.com/blogs/cwdn/2013/09/what-is-bare-metal-cloud.html" class="external text">&quot;What is bare-metal cloud?&quot;</a>. *[Computer Weekly](//en.wikipedia.org/wiki/Computer_Weekly "Computer Weekly") Application Developer Network*.<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rfr_id=info%3Asid%2Fen.wikipedia.org%3ABare-metal+server&amp;rft.atitle=What+is+bare-metal+cloud%3F&amp;rft.au=Adrian+Bridgwater&amp;rft.date=2013-09-06&amp;rft.genre=unknown&amp;rft_id=http%3A%2F%2Fwww.computerweekly.com%2Fblogs%2Fcwdn%2F2013%2F09%2Fwhat-is-bare-metal-cloud.html&amp;rft.jtitle=Computer+Weekly+Application+Developer+Network&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal"><span style="display:none;"> </span></span></span>

